@@ -40,12 +40,14 @@ import java.lang.reflect.AccessibleObject;
 import java.lang.reflect.Modifier;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
+import java.util.HashMap;
 
 
 /**
  * An ASM-based implementation of Paranamer. It relies on debug information compiled
  * with the "-g" javac option to retrieve parameter names.
- *
+ * <p/>
  * Portions of this source file are a fork of ASM.
  *
  * @author Guilherme Silveira
@@ -54,6 +56,17 @@ import java.util.List;
 public class BytecodeReadingParanamer implements Paranamer {
 
     private static final String[] EMPTY_NAMES = new String[]{};
+    private static final Map primitives = new HashMap() {
+        {
+            put("int","I");
+            put("boolean","Z");
+            put("char","C");
+            put("short","B");
+            put("float","F");
+            put("long","J");
+            put("double","D");
+        }
+    };
 
     public String[] lookupParameterNames(AccessibleObject methodOrCtor) {
 
@@ -117,11 +130,14 @@ public class BytecodeReadingParanamer implements Paranamer {
 
     private InputStream getClassAsStream(Class clazz) {
         ClassLoader classLoader = clazz.getClassLoader();
+        if (classLoader == null) {
+            classLoader = ClassLoader.getSystemClassLoader();
+        }
         return getClassAsStream(classLoader, clazz.getName());
     }
 
     private InputStream getClassAsStream(ClassLoader classLoader, String className) {
-        String name = className.replace('.', '/') + ".class";  
+        String name = className.replace('.', '/') + ".class";
         // better pre-cache all methods otherwise this content will be loaded
         // multiple times
         InputStream asStream = classLoader.getResourceAsStream(name);
@@ -207,7 +223,12 @@ public class BytecodeReadingParanamer implements Paranamer {
             String s = argumentTypes[i].getClassName();
             // array notation needs cleanup.
             if (s.endsWith("[]")) {
-                s = "[L" + s.substring(0, s.length() - 2) + ";";
+                String prefix = s.substring(0, s.length() - 2);
+                if (primitives.containsKey(prefix)) {
+                    s = "[" + primitives.get(prefix);
+                } else {
+                s = "[L" + prefix + ";";
+                }
             }
             return s;
         }
